#ifndef INCLUDED_GCTP_H
#define INCLUDED_GCTP_H

typedef long (*ForwardTransFunc)(double, double, double*, double*);
typedef long (*InverseTransFunc)(double, double, double*, double*);

#endif  /* INCLUDED_GCTP_H */
